@@ -1,4 +1,4 @@
-/* $Id: tftp.c,v 1.10 2001/11/13 03:39:32 hpa Exp $ */
+/* $Id: tftp.c,v 1.11 2001/11/13 04:16:12 hpa Exp $ */
 
 /* $OpenBSD: tftp.c,v 1.4 1997/08/06 06:43:45 deraadt Exp $	*/
 /* $NetBSD: tftp.c,v 1.5 1995/04/29 05:55:25 cgd Exp $	*/
@@ -42,7 +42,7 @@
 /* static char sccsid[] = "@(#)tftp.c	8.1 (Berkeley) 6/6/93"; */
 /* static char rcsid[] = "$OpenBSD: tftp.c,v 1.4 1997/08/06 06:43:45 deraadt Exp $"; */
 static const char *rcsid UNUSED =
-"tftp-hpa $Id: tftp.c,v 1.10 2001/11/13 03:39:32 hpa Exp $";
+"tftp-hpa $Id: tftp.c,v 1.11 2001/11/13 04:16:12 hpa Exp $";
 #endif /* not lint */
 
 /* Many bug fixes are from Jim Guyton <guyton@rand-unix> */
@@ -137,7 +137,7 @@ tftp_sendfile(int fd, char *name, char *mode)
 		}
 		timeout = 0;
 		(void) sigsetjmp(timeoutbuf,1);
-send_data:
+
 		if (trace)
 			tpacket("sent", dp, size + 4);
 		n = sendto(f, dp, size + 4, 0,
@@ -184,9 +184,11 @@ send_data:
 					printf("discarded %d packets\n",
 							j);
 				}
-				if (ap->th_block == (block-1)) {
-					goto send_data;
-				}
+				/*
+				 * RFC1129/RFC1350: We MUST NOT re-send the DATA
+				 * packet in response to an invalid ACK.  Doing so
+				 * would cause the Sorcerer's Apprentice bug.
+				 */
 			}
 		}
 		if ( !is_request )
