@@ -1,4 +1,4 @@
-/* tftp-hpa: $Id: tftpd.c,v 1.34 2001/11/13 03:11:52 hpa Exp $ */
+/* tftp-hpa: $Id: tftpd.c,v 1.35 2001/11/13 04:16:12 hpa Exp $ */
 
 /* $OpenBSD: tftpd.c,v 1.13 1999/06/23 17:01:36 deraadt Exp $	*/
 
@@ -45,7 +45,7 @@ static const char *copyright UNUSED =
 /*static char sccsid[] = "from: @(#)tftpd.c	5.13 (Berkeley) 2/26/91";*/
 /*static char rcsid[] = "$OpenBSD: tftpd.c,v 1.13 1999/06/23 17:01:36 deraadt Exp $: tftpd.c,v 1.6 1997/02/16 23:49:21 deraadt Exp $";*/
 static const char *rcsid UNUSED =
-"tftp-hpa $Id: tftpd.c,v 1.34 2001/11/13 03:11:52 hpa Exp $";
+"tftp-hpa $Id: tftpd.c,v 1.35 2001/11/13 04:16:12 hpa Exp $";
 #endif /* not lint */
 
 /*
@@ -978,7 +978,6 @@ tftp_sendfile(struct formats *pf, struct tftphdr *oap, int oacklen)
     timeout = 0;
     (void) sigsetjmp(timeoutbuf,1);
     
-  send_data:
     if (send(peer, dp, size + 4, 0) != size + 4) {
       syslog(LOG_ERR, "tftpd: write: %m");
       goto abort;
@@ -1005,9 +1004,11 @@ tftp_sendfile(struct formats *pf, struct tftphdr *oap, int oacklen)
 	}
 				/* Re-synchronize with the other side */
 	(void) synchnet(peer);
-	if (ap->th_block == (block -1)) {
-	  goto send_data;
-	}
+	/*
+	 * RFC1129/RFC1350: We MUST NOT re-send the DATA
+	 * packet in response to an invalid ACK.  Doing so
+	 * would cause the Sorcerer's Apprentice bug.
+	 */
       }
       
     }
